.. lephare documentation main file.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

LePHARE (PHotometric Analysis for Redshift Estimation)
========================================================================================

.. image:: https://avatars.githubusercontent.com/u/165841626?s=400&u=ff86bd4c19a9d36958cf1b47d84849dbe25c274a&v=4
   :alt: LePHARE logo
   :align: center
   :width: 150px

Since 1999 LePHARE has been a code for computing photometric redshifts and 
physical parameters by fitting spectral energy distributions (SED) to a dataset 
of photometric fluxes or apparent magnitudes. 
LePHARE was originally written in fortran (Arnout et al. 1999; Ilbert et al. 2006). 
It has been completely rewritten in C++ with a Python interface with a larger team of developpers including
J. Cohen-Tanugi and R. Shirley.

.. note::

   This is the official version of LePHARE in C++/Python. It is in active development. The 
   deprecated version can be found `here <https://gitlab.lam.fr/Galaxies/LEPHARE>`_ in case you have legacy code that depends on it.


.. toctree::
   :hidden:

   Home page <self>
   Getting Started <getting_started>
   Advanced Installation <advanced_install>
   Usage with Python Interface <python_usage>
   Usage with Command Line Interface <commandline_usage>
   Detailed documentation <detailed>
   Keywords <keywords>
   C API Reference <doxygen_output/c_lib/library_root>
   Python API Reference <autoapi/index>
   Known issues <known_issues>
   Acknowledgements <acknowledgements>
